# React UI library for Segment
> Presentational React Components with a coherent API for developers

* React Storybook with Documentation
* Incremental UI Engineering workflow with smart defaults
* Design changes should not break API
* Powerful `<Box />` base components

## Install

```
$ yarn add @segment/react-ui-library
```

## React Storybook and Documentation

React Storybook will be used as a reference and documentation for most components.

```
yarn run storybook
```

Open [http://localhost:9009/](http://localhost:9009/) to see the Storybook

## Usage

Using the `react-ui-library` should be fairly straightforward.
Install and then import whatever components you need:

```jsx
import React from 'react'
import ReactDOM from 'react-dom'
import {
  App
} from '@segment/react-ui-library'

ReactDOM.render(<App />, document.getElementById('root'))
```

Make sure to always use the `<App />` component.

Read the Storybook for more documentation.

## How to publish

Be sure to update the `package.json` version accordingly if you make changes.
Common workflow is to commit and then run `npm version patch`.

Avoid breaking changes in patches.

```
$ npm version {patch,minor,major}
```

* `patch`: `0.0.1`
* `minor`: `0.1.0`
* `major`: `1.0.0`

## Incremental UI Engineering workflow with smart defaults

The Components in the UI Library should be as presentational as possible.
Components can still be class based if setState is important for UI interactions: Popover, Sheet.

## Creating new components

1. Create a new component in `/src/components`

As an example here is a basic boilerplate:

```jsx
import React, { PropTypes } from 'react'
import styled, { css } from 'styled-components'
import Box from './Box'

// Use this to apply a class through styled-components
// Useful if you need psuedo selectors, autoprefixing or media queries
// Write css as you are used to.
// Autoprefixed in the end
// Might cause minor FOUC in some cases
const styles = ({
  theme
}) => css`
  /* write css here if needed */
`

// Alternatively, or additionally, you can use inline styles
// Although less powerful in some ways.
// They are more robust and have less dependency.
// Filter out props you don't want to pass on
const parseProps = ({ style, ...props }) => {
  const newStyles = {}

  // ... add to newStyles here

  return { style: { ...newStyles, ...style }, ...props }
}

const Comp = styled(({ ...props }) =>
  React.createElement(Box, parseProps(props)))`${styles}`

Comp.propTypes = {
  ...Box.propType
}

Comp.displayName = 'Comp'

export default Comp
```

2. Create a new story in `/src/stories` with documentation

## TODO

- [ ] Cleanup Spacing and Space component, might remove
- [ ] Checkbox component
- [x] Input component
- [ ] Spinner component
- [x] SideSheet component
- [ ] BottomSheet component
- [ ] Popover component
- [ ] Port over remaining properties in Box to enhancers
- [ ] Implement a currentColor API for contextual colors
- [x] Remove create-react-app stuff
